@@ -2,9 +2,11 @@
 from trdb2py.config import loadConfig
 from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading, getAssetCandles2
 from trdb2py.utils import str2asset, nextWeekDay, asset2str
-from trdb2py.timeutils import str2timestamp
-from trdb2py.pdutils import (buildPNLReport, getPNLLastTs, getPNLValueWithTimestamp, mergePNL,
-                             rmPNLValuesWithTimestamp, getPNLTimestampLowInMonth, getPNLTimestampHighInMonth)
+from trdb2py.timeutils import str2timestamp, getDayInYear, getYearDays
+from trdb2py.pdutils import (buildPNLReport, getPNLLastTs, getPNLValueWithTimestamp, mergePNL, mergePNLEx,
+                             rmPNLValuesWithTimestamp, getPNLTimestampLowInMonth, getPNLTimestampHighInMonth,
+                             countTradingDays4Year, calcAnnualizedVolatility, rebuildPNL, rebuildDrawdown,
+                             calcAnnualizedReturns, calcSharpe)
 from trdb2py.statistics import (calcPNLWinRateInYear, buildPNLWinRateInYears,
                                 buildPNLWinRateInMonths, buildPNLListWinRateInYears2,
                                 buildPNLListWinRateInMonths2, buildPNLListWinRate4Month,
